package com.zswl.cloud.springBtach.server.core.service;


import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.security.helper.AuthHelper;
import com.xiaoju.open.oil.commons.OilRequest;
import com.xiaoju.open.oil.commons.config.OilConfig;
import com.xiaoju.open.oil.core.QueryClient;
import com.xiaoju.open.oil.core.QueryClientFactory;
import com.xiaoju.open.oil.core.executor.ResponseDTO;
import com.xiaoju.open.oil.interfaces.request.NotificationPushStoreInfoRequest;
import com.xiaoju.open.oil.interfaces.request.NotificationReceiveRefundRequest;
import com.xiaoju.open.oil.interfaces.request.QueryApiStorePriceRequest;
import com.xiaoju.open.oil.interfaces.request.QueryStoreDetailRequest;
import com.xiaoju.open.oil.interfaces.response.QueryApiStorePriceResponse;
import com.xiaoju.open.oil.interfaces.response.QueryStoreDetailResponse;
import com.xiaoju.open.oil.security.secret.SecurityService;
import com.zswl.cloud.springBatch.client.model.request.NearbyModel;
import com.zswl.cloud.springBtach.server.core.dao.XiaoJuStoreDao;
import com.zswl.cloud.springBtach.server.core.domain.XiaoJuStore;
import io.swagger.util.Json;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class XiaoJuService {


    private static final Logger log = LoggerFactory.getLogger(XiaoJuService.class);
    @Autowired
    AuthHelper authHelper;

    @Autowired
    XiaoJuStoreDao xiaoJuStoreDao;

    @Autowired
    OilConfig oilConfig;

    // 查询加油站详情
    public ResponseDTO notificationPushStoreInfoRequest(OilRequest oilRequest) {

        log.info("加油站通知原始数据：{}", oilRequest);

        String s = SecurityService.genDecodeData(oilRequest.getData(), oilConfig.getDataSecret(), oilConfig.getDataSecretIV());

        log.info("通知 加油站详情：{}", s);
        XiaoJuStore xiaoJuStore = JSONUtil.toBean(s, XiaoJuStore.class);

        XiaoJuStore byStoreId = xiaoJuStoreDao.findByStoreId(xiaoJuStore.getStoreId());
        if (byStoreId != null) {
            BeanUtils.copyProperties(byStoreId, xiaoJuStore, "id","updateTime");
            byStoreId.setLocation(new double[]{xiaoJuStore.getLon(), xiaoJuStore.getLat()});
            xiaoJuStoreDao.save(byStoreId);
        }else {
            xiaoJuStore.setLocation(new double[]{xiaoJuStore.getLon(), xiaoJuStore.getLat()});
            xiaoJuStoreDao.save(xiaoJuStore);
        }




        String data = SecurityService.genEncodeData("{\"success\":true,\"msg\":\"ok\"}", oilConfig.getDataSecret(), oilConfig.getDataSecretIV());
        String sig = SecurityService.genSigData(data, oilConfig.getDataSecret());
        ResponseDTO responseDTO = new ResponseDTO();
        responseDTO.setAppKey(oilConfig.getAppId());
        responseDTO.setCode("0");
        responseDTO.setMsg("请求成功");
        responseDTO.setData(data);
        responseDTO.setSig(sig);
        return responseDTO;

    }

    public ResponseDTO notifyOrderInfo(OilRequest oilRequest) {


        String s = SecurityService.genDecodeData(oilRequest.getData(), oilConfig.getDataSecret(), oilConfig.getDataSecretIV());

        log.info("通知 加油站详情：{}", s);
        NotificationReceiveRefundRequest xiaoJuStore = JSONUtil.toBean(s, NotificationReceiveRefundRequest.class);


        String data = SecurityService.genEncodeData("{\"success\":true,\"msg\":\"ok\"}", oilConfig.getDataSecret(), oilConfig.getDataSecretIV());
        String sig = SecurityService.genSigData(data, oilConfig.getDataSecret());
        ResponseDTO responseDTO = new ResponseDTO();
        responseDTO.setAppKey(oilConfig.getAppId());
        responseDTO.setCode("0");
        responseDTO.setMsg("请求成功");
        responseDTO.setData(data);
        responseDTO.setSig(sig);
        return responseDTO;

    }

    public ResultContent<QueryStoreDetailResponse> queryStoreDetail(String storeId) {
        XiaoJuStore byStoreId = xiaoJuStoreDao.findByStoreId(storeId);
        QueryStoreDetailRequest queryStoreDetailRequest = new QueryStoreDetailRequest();

        queryStoreDetailRequest.setOutUserId(authHelper.getCurrentUser().getUserId());
        queryStoreDetailRequest.setStoreId(storeId);
        queryStoreDetailRequest.setLat(byStoreId.getLat());
        queryStoreDetailRequest.setLon(byStoreId.getLon());
        queryStoreDetailRequest.setOpenChannel(1);

        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        QueryStoreDetailResponse queryStoreDetailResponse = queryClient.api().queryStoreDetail(queryStoreDetailRequest);

        return ResultContent.buildContent(queryStoreDetailResponse);
    }

    public ResultContent<List<QueryApiStorePriceResponse>> queryStorePrice(String storeId) {
        QueryApiStorePriceRequest queryApiStorePriceRequest = new QueryApiStorePriceRequest();
        queryApiStorePriceRequest.setOpenChannel(1);
        queryApiStorePriceRequest.setOutUserId("dajihao2");
        List<String> list = new ArrayList<>();
        list.add("5154031457384536897");
        queryApiStorePriceRequest.setStoreIds(list);


        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        List<QueryApiStorePriceResponse> list1 = queryClient.api().queryStorePrice(queryApiStorePriceRequest);
        return ResultContent.buildContent(list1);
    }


    public ResultContent<List<XiaoJuStore>> nearbyStore(NearbyModel nearbyModel) {

        List<XiaoJuStore> nearbyTargets = xiaoJuStoreDao.findNearbyTargets(nearbyModel);
        return ResultContent.buildContent(nearbyTargets);
    }


}
